@@ -1,4 +1,4 @@
-#![no_std]
+//#![no_std]
 
 //! Common messages for [stratum v2][Sv2]
 //! The following protocol messages are common across all of the sv2 (sub)protocols.
